initGooglePay abstract method
- required String merchantName,
- List<
TapPayCardAuthMethod> ? allowedAuthMethods, - List<
TapPayCardType> ? allowedCardTypes, - bool? isPhoneNumberRequired = false,
- bool? isEmailRequired = false,
- bool? isBillingAddressRequired = false,
Initialize Google Pay
merchantName is the name of the merchant. (e.g., "Google Pay Merchant")
allowedAuthMethods is the list of allowed authentication methods. Default value is TapPayCardAuthMethod.panOnly and TapPayCardAuthMethod.cryptogram3DS
allowedCardTypes is the list of allowed card networks. Default value is TapPayCardType.visa, TapPayCardType.masterCard, TapPayCardType.americanExpress, TapPayCardType.jcb
isPhoneNumberRequired is a boolean value to indicate whether to require phone number. Default value is false
isEmailRequired is a boolean value to indicate whether to require email. Default value is false
isBillingAddressRequired is a boolean value to indicate whether to require billing address. Default value is false
return GooglePayInitResult with value success as true if success.
return GooglePayInitResult with value success as false if fail.
return GooglePayInitResult with value message as String if fail.
return null if the initialization is incomplete
Implementation
Future<TapPaySdkCommonResult?> initGooglePay({
required String merchantName,
List<TapPayCardAuthMethod>? allowedAuthMethods,
List<TapPayCardType>? allowedCardTypes,
bool? isPhoneNumberRequired = false,
bool? isEmailRequired = false,
bool? isBillingAddressRequired = false,
});